@@ -3,14 +3,14 @@
 /**
  * global.php
  *
- * Copyright (c) 1999-2005 The SquirrelMail Project Team
+ * Copyright (c) 1999-2006 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This includes code to update < 4.1.0 globals to the newer format
  * It also has some session register functions that work across various
  * php versions.
  *
- * @version $Id: global.php,v 1.27.2.11 2005/04/14 10:52:45 pdontthink Exp $
+ * @version $Id: global.php,v 1.27.2.15 2006/02/03 22:27:47 jervfors Exp $
  * @package squirrelmail
  */
 
@@ -303,9 +303,9 @@ function sqsession_destroy() {
 
     global $base_uri;
 
-    if (isset($_COOKIE[session_name()])) setcookie(session_name(), '', time() - 5, $base_uri);
-    if (isset($_COOKIE['username'])) setcookie('username','',time() - 5,$base_uri);
-    if (isset($_COOKIE['key'])) setcookie('key','',time() - 5,$base_uri);
+    if (isset($_COOKIE[session_name()])) setcookie(session_name(), '', 0, $base_uri);
+    if (isset($_COOKIE['username'])) setcookie('username', '', 0, $base_uri);
+    if (isset($_COOKIE['key'])) setcookie('key', '', 0, $base_uri);
 
     $sessid = session_id();
     if (!empty( $sessid )) {
@@ -336,4 +336,4 @@ function sqsession_is_active() {
 }
 
 // vim: et ts=4
-?>
+?>
\ No newline at end of file
