@@ -3,13 +3,13 @@
 /**
  * mailbox_display.php
  *
- * Copyright (c) 1999-2005 The SquirrelMail Project Team
+ * Copyright (c) 1999-2006 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This contains functions that display mailbox information, such as the
  * table row that has sender, date, subject, etc...
  *
- * @version $Id: mailbox_display.php,v 1.321.2.26 2005/04/09 17:41:06 jangliss Exp $
+ * @version $Id: mailbox_display.php,v 1.321.2.32 2006/02/03 22:27:47 jervfors Exp $
  * @package squirrelmail
  */
 
@@ -52,7 +52,10 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
            $thread_sort_messages, /* thread sorting on/off */
            $server_sort_order, /* sort value when using server-sorting */
            $row_count,
-           $allow_server_sort; /* enable/disable server-side sorting */
+           $allow_server_sort, /* enable/disable server-side sorting */
+           $truncate_subject,
+           $truncate_sender;
+
     $color_string = $color[4];
 
     if ($GLOBALS['alt_index_colors']) {
@@ -195,8 +198,8 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
     $checked = ($checkall == 1) ? ' CHECKED' : '';
     $col = 0;
     $msg['SUBJECT'] = decodeHeader($msg['SUBJECT']);
-    $subject = processSubject($msg['SUBJECT'], $indent_array[$msg['ID']]);
-    $subject = str_replace('&nbsp;',' ',$subject);
+//    $subject = processSubject($msg['SUBJECT'], $indent_array[$msg['ID']]);
+    $subject = truncateWithEntities(str_replace('&nbsp;',' ',$msg['SUBJECT']), $truncate_subject);
     if (sizeof($index_order)) {
         foreach ($index_order as $index_order_part) {
             switch ($index_order_part) {
@@ -210,7 +213,7 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                 $from_xtra = '';
                 $from_xtra = 'title="' . $senderFrom . '"';
                 echo html_tag( 'td',
-                               $italic . $bold . $flag . $fontstr . $senderName .
+                               $italic . $bold . $flag . $fontstr . truncateWithEntities($senderName, $truncate_sender) .
                                $fontstr_end . $flag_end . $bold_end . $italic_end,
                                'left',
                                $hlt_color, $from_xtra );
@@ -491,8 +494,12 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
     $start_msg = $res[0];
     $end_msg   = $res[1];
 
-    $paginator_str = get_paginator_str($mailbox, $start_msg, $end_msg,
-                                       $num_msgs, $show_num, $sort);
+    if ($num_msgs > 0) {
+        $paginator_str = get_paginator_str($mailbox, $start_msg, $end_msg,
+                                           $num_msgs, $show_num, $sort);
+    } else {
+        $paginator_str = '';
+    }
 
     $msg_cnt_str = get_msgcnt_str($start_msg, $end_msg, $num_msgs);
 
@@ -687,12 +694,10 @@ function mail_message_listing_beginning ($imapConnection,
     if (!isset($msg)) {
         $msg = '';
     }
-    $moveFields = '<input type="hidden" name="msg" value="'.htmlspecialchars($msg).'">' .
-		  '<input type="hidden" name="mailbox" value="'.htmlspecialchars($mailbox).'">' .
-		  '<input type="hidden" name="startMessage" value="'.htmlspecialchars($start_msg).'">';
+    $moveFields = '<input type="hidden" name="msg" value="'.htmlspecialchars($msg).'">' . "\n" .
+		  '<input type="hidden" name="mailbox" value="'.htmlspecialchars($mailbox).'">' . "\n" .
+		  '<input type="hidden" name="startMessage" value="'.htmlspecialchars($start_msg).'">' . "\n";
 
-//    $moveURL = "move_messages.php?msg=$msg&amp;mailbox=$urlMailbox"
-//             . "&amp;startMessage=$start_msg";
     /*
      * This is the beginning of the message list table.
      * It wraps around all messages
@@ -700,8 +705,11 @@ function mail_message_listing_beginning ($imapConnection,
     $safe_name = preg_replace("/[^0-9A-Za-z_]/", '_', $mailbox);
     $form_name = "FormMsgs" . $safe_name;
     echo '<form name="' . $form_name . '" method="post" action="move_messages.php">' ."\n"
-	. $moveFields
-        . html_tag( 'table' ,
+        . $moveFields . "\n";
+
+    if (!empty($paginator) && !empty($msg_cnt_str)) {
+
+        echo html_tag( 'table' ,
             html_tag( 'tr',
                 html_tag( 'td' ,
                     html_tag( 'table' ,
@@ -713,8 +721,9 @@ function mail_message_listing_beginning ($imapConnection,
                 , 'left', '', '' )
             , '', $color[0] )
 	    , '', '', 'border="0" width="100%" cellpadding="1"  cellspacing="0"' );
+    }
 	/* line between header and button area */
-        echo '<tr><td HEIGHT="5" BGCOLOR="'.$color[4].'"></td></tr>';
+        echo '</td></tr><tr><td HEIGHT="5" BGCOLOR="'.$color[4].'"></td></tr>';
 
         echo '<tr><td>';
         echo html_tag( 'tr' ) . "\n"
