@@ -3,13 +3,13 @@
 /**
  * strings.php
  *
- * Copyright (c) 1999-2005 The SquirrelMail Project Team
+ * Copyright (c) 1999-2006 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This code provides various string manipulation functions that are
  * used by the rest of the Squirrelmail code.
  *
- * @version $Id: strings.php,v 1.184.2.35 2005/07/13 18:37:52 jangliss Exp $
+ * @version $Id: strings.php,v 1.184.2.46 2006/02/23 21:17:44 kink Exp $
  * @package squirrelmail
  */
 
@@ -17,14 +17,14 @@
  * SquirrelMail version number -- DO NOT CHANGE
  */
 global $version;
-$version = '1.4.5';
+$version = '1.4.6';
 
 /**
  * SquirrelMail internal version number -- DO NOT CHANGE
  * $sm_internal_version = array (release, major, minor)
  */
 global $SQM_INTERNAL_VERSION;
-$SQM_INTERNAL_VERSION = array(1,4,5);
+$SQM_INTERNAL_VERSION = array(1,4,6);
 
 /**
  * There can be a circular issue with includes, where the $version string is
@@ -42,7 +42,7 @@ require_once(SM_PATH . 'functions/global.php');
  * Specifically, &#039 comes up as 5 characters instead of 1.
  * This should not add newlines to the end of lines.
  */
-function sqWordWrap(&$line, $wrap) {
+function sqWordWrap(&$line, $wrap, $charset=null) {
     global $languages, $squirrelmail_language;
 
     if (isset($languages[$squirrelmail_language]['XTRA_CODE']) &&
@@ -67,9 +67,9 @@ function sqWordWrap(&$line, $wrap) {
     while ($i < count($words)) {
         /* Force one word to be on a line (minimum) */
         $line .= $words[$i];
-        $line_len = strlen($beginning_spaces) + strlen($words[$i]) + 2;
+        $line_len = strlen($beginning_spaces) + sq_strlen($words[$i],$charset) + 2;
         if (isset($words[$i + 1]))
-            $line_len += strlen($words[$i + 1]);
+            $line_len += sq_strlen($words[$i + 1],$charset);
         $i ++;
 
         /* Add more words (as long as they fit) */
@@ -77,7 +77,7 @@ function sqWordWrap(&$line, $wrap) {
             $line .= ' ' . $words[$i];
             $i++;
             if (isset($words[$i]))
-                $line_len += strlen($words[$i]) + 1;
+                $line_len += sq_strlen($words[$i],$charset) + 1;
             else
                 $line_len += 1;
         }
@@ -134,6 +134,54 @@ function sqUnWordWrap(&$body) {
     $body .= "\n";
 }
 
+/**
+ * Truncates a string and take care of html encoded characters
+ *
+ * @param string  $s string to truncate
+ * @param int $iTrimAt Trim at nn characters
+ * @return string  Trimmed string
+ */
+function truncateWithEntities($s, $iTrimAt) {
+    global $languages, $squirrelmail_language;
+
+    $ent_strlen = strlen($s);
+    if (($iTrimAt <= 0) || ($ent_strlen <= $iTrimAt))
+        return $s;
+
+
+    if (isset($languages[$squirrelmail_language]['XTRA_CODE']) &&
+        function_exists($languages[$squirrelmail_language]['XTRA_CODE'])) {
+            return $languages[$squirrelmail_language]['XTRA_CODE']('strimwidth', $s, $iTrimAt);
+    } else {
+        /*
+         * see if this is entities-encoded string
+         * If so, Iterate through the whole string, find out
+         * the real number of characters, and if more
+         * than $iTrimAt, substr with an updated trim value.
+         */
+        $trim_val = $iTrimAt;
+        $ent_offset = 0;
+        $ent_loc = 0;
+        while ( $ent_loc < $trim_val && (($ent_loc = strpos($s, '&', $ent_offset)) !== false) &&
+                (($ent_loc_end = strpos($s, ';', $ent_loc+3)) !== false) ) {
+            $trim_val += ($ent_loc_end-$ent_loc);
+            $ent_offset  = $ent_loc_end+1;
+        }
+
+        if (($trim_val > $iTrimAt) && ($ent_strlen > $trim_val) && (strpos($s,';',$trim_val) < ($trim_val + 6))) {
+            $i = strpos($s,';',$trim_val);
+            if ($i !== false) {
+                $trim_val = strpos($s,';',$trim_val)+1;
+            }
+        }
+        // only print '...' when we're actually dropping part of the subject
+        if ($ent_strlen <= $trim_val)
+            return $s;
+    }
+
+    return substr_replace($s, '...', $trim_val);
+}
+
 /**
  * If $haystack is a full mailbox name and $needle is the mailbox
  * separator character, returns the last part of the mailbox name.
@@ -184,6 +232,28 @@ function php_self () {
 }
 
 
+/**
+ * Find out where squirrelmail lives and try to be smart about it.
+ * The only problem would be when squirrelmail lives in directories
+ * called "src", "functions", or "plugins", but people who do that need
+ * to be beaten with a steel pipe anyway.
+ *
+ * @return string the base uri of squirrelmail installation.
+ */
+function sqm_baseuri(){
+    global $base_uri, $PHP_SELF;
+    /**
+     * If it is in the session, just return it.
+     */
+    if (isset($base_uri)){
+        return $base_uri;
+    }
+    $dirs = array('|src/.*|', '|plugins/.*|', '|functions/.*|');
+    $repl = array('', '', '');
+    $base_uri = preg_replace($dirs, $repl, $PHP_SELF);
+    return $base_uri;
+}
+
 /**
  * get_location
  *
@@ -620,7 +690,7 @@ function sq_fwrite($fp, $string) {
  * @param string $string tested string
  * @param string $charset charset used in a string
  * @return bool true if 8bit symbols are detected
- * @since 1.4.4
+ * @since 1.5.1 and 1.4.4
  */
 function sq_is8bit($string,$charset='') {
     global $default_charset;
@@ -642,5 +712,139 @@ function sq_is8bit($string,$charset='') {
     return preg_match("$needle",$string);
 }
 
+/**
+ * Function returns number of characters in string.
+ *
+ * Returned number might be different from number of bytes in string,
+ * if $charset is multibyte charset. Detection depends on mbstring
+ * functions. If mbstring does not support tested multibyte charset,
+ * vanilla string length function is used.
+ * @param string $str string
+ * @param string $charset charset
+ * @since 1.5.1 and 1.4.6
+ * @return integer number of characters in string
+ */
+function sq_strlen($str, $charset=null){
+    // default option
+    if (is_null($charset)) return strlen($str);
+
+    // lowercase charset name
+    $charset=strtolower($charset);
+
+    // use automatic charset detection, if function call asks for it
+    if ($charset=='auto') {
+        global $default_charset;
+        set_my_charset();
+        $charset=$default_charset;
+    }
+
+    // Use mbstring only with listed charsets
+    $aList_of_mb_charsets=array('utf-8','big5','gb2312','gb18030','euc-jp','euc-cn','euc-tw','euc-kr');
+
+    // calculate string length according to charset
+    if (in_array($charset,$aList_of_mb_charsets) && in_array($charset,sq_mb_list_encodings())) {
+        $real_length = mb_strlen($str,$charset);
+    } else {
+        // own strlen detection code is removed because missing strpos,
+        // strtoupper and substr implementations break string wrapping.
+        $real_length=strlen($str);
+    }
+    return $real_length;
+}
+
+/**
+ * Replacement of mb_list_encodings function
+ *
+ * This function provides replacement for function that is available only
+ * in php 5.x. Function does not test all mbstring encodings. Only the ones
+ * that might be used in SM translations.
+ *
+ * Supported strings are stored in session in order to reduce number of
+ * mb_internal_encoding function calls.
+ *
+ * If mb_list_encodings() function is present, code uses it. Main difference
+ * from original function behaviour - array values are lowercased in order to
+ * simplify use of returned array in in_array() checks.
+ *
+ * If you want to test all mbstring encodings - fill $list_of_encodings
+ * array.
+ * @return array list of encodings supported by php mbstring extension
+ * @since 1.5.1 and 1.4.6
+ */
+function sq_mb_list_encodings() {
+    // check if mbstring extension is present
+    if (! function_exists('mb_internal_encoding'))
+        return array();
+
+    // php 5+ function
+    if (function_exists('mb_list_encodings')) {
+        $ret = mb_list_encodings();
+        array_walk($ret,'sq_lowercase_array_vals');
+        return $ret;
+    }
+
+    // don't try to test encodings, if they are already stored in session
+    if (sqgetGlobalVar('mb_supported_encodings',$mb_supported_encodings,SQ_SESSION))
+        return $mb_supported_encodings;
+
+    // save original encoding
+    $orig_encoding=mb_internal_encoding();
+
+    $list_of_encoding=array(
+        'pass',
+        'auto',
+        'ascii',
+        'jis',
+        'utf-8',
+        'sjis',
+        'euc-jp',
+        'iso-8859-1',
+        'iso-8859-2',
+        'iso-8859-7',
+        'iso-8859-9',
+        'iso-8859-15',
+        'koi8-r',
+        'koi8-u',
+        'big5',
+        'gb2312',
+        'gb18030',
+        'windows-1251',
+        'windows-1255',
+        'windows-1256',
+        'tis-620',
+        'iso-2022-jp',
+        'euc-cn',
+        'euc-kr',
+        'euc-tw',
+        'uhc',
+        'utf7-imap');
+
+    $supported_encodings=array();
+
+    foreach ($list_of_encoding as $encoding) {
+        // try setting encodings. suppress warning messages
+        if (@mb_internal_encoding($encoding))
+            $supported_encodings[]=$encoding;
+    }
+
+    // restore original encoding
+    mb_internal_encoding($orig_encoding);
+
+    // register list in session
+    sqsession_register($supported_encodings,'mb_supported_encodings');
+
+    return $supported_encodings;
+}
+
+/**
+ * Callback function used to lowercase array values.
+ * @param string $val array value
+ * @param mixed $key array key
+ * @since 1.5.1 and 1.4.6
+ */
+function sq_lowercase_array_vals(&$val,$key) {
+    $val = strtolower($val);
+}
+
 $PHP_SELF = php_self();
 ?>
