@@ -3,13 +3,13 @@
 /**
  * empty_trash.php
  *
- * Copyright (c) 1999-2005 The SquirrelMail Project Team
+ * Copyright (c) 1999-2006 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * Handles deleting messages from the trash folder without
  * deleting subfolders.
  *
- * @version $Id: empty_trash.php,v 1.44.2.4 2005/04/05 13:30:13 kink Exp $
+ * @version $Id: empty_trash.php,v 1.44.2.7 2006/02/03 22:27:55 jervfors Exp $
  * @package squirrelmail
  */
 
@@ -76,6 +76,7 @@ sqimap_logout($imap_stream);
 session_write_close();
 
 $location = get_location();
-header ("Location: $location/left_main.php");
+// force_refresh = 1 in case trash contains deleted mailboxes
+header ("Location: $location/left_main.php?force_refresh=1");
 
-?>
+?>
\ No newline at end of file
