@@ -3,16 +3,20 @@
 /**
  * options.php
  *
- * Copyright (c) 1999-2004 The SquirrelMail Project Team
+ * Copyright (c) 1999-2006 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * Displays the options page. Pulls from proper user preference files
  * and config.php. Displays preferences as selected and other options.
  *
- * $Id: options.php,v 1.121.2.6 2004/04/19 20:23:29 kink Exp $
+ * @version $Id: options.php,v 1.121.2.13 2006/02/03 22:27:55 jervfors Exp $
+ * @package squirrelmail
  */
 
-/* Path for SquirrelMail required files. */
+/**
+ * Path for SquirrelMail required files.
+ * @ignore
+ */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -51,7 +55,7 @@ function process_optionmode_submit($optpage, $optpage_data) {
             echo "name = '$option->name', "
                . "value = '$option->value', "
                . "new_value = '$option->new_value'\n";
-            echo "<br>";
+            echo "<br />";
             */
             if ($option->changed()) {
                 $option->save();
@@ -121,7 +125,7 @@ sqgetGlobalVar('onetimepad',$onetimepad,    SQ_SESSION);
 sqgetGlobalVar('delimiter', $delimiter,     SQ_SESSION);
 
 sqgetGlobalVar('optpage',     $optpage);
-sqgetGlobalVar('optmode',     $optmode, SQ_FORM);
+sqgetGlobalVar('optmode',     $optmode,      SQ_FORM);
 sqgetGlobalVar('optpage_data',$optpage_data, SQ_POST);
 /* end of getting globals */
 
@@ -206,6 +210,9 @@ if ( !@is_file( $optpage_file ) ) {
 /*** Next, process anything that needs to be processed. ***/
 /***********************************************************/
 
+// set empty error message
+$optpage_save_error=array();
+
 if ( isset( $optpage_data ) ) {
     switch ($optmode) {
         case SMOPT_MODE_SUBMIT:
@@ -268,7 +275,7 @@ displayPageHeader($color, 'None', (isset($optpage_data['xtra']) ? $optpage_data[
 echo html_tag( 'table', '', 'center', $color[0], 'width="95%" cellpadding="1" cellspacing="0" border="0"' ) . "\n" .
         html_tag( 'tr' ) . "\n" .
             html_tag( 'td', '', 'center' ) .
-                "<b>$optpage_title</b><br>\n".
+                "<b>$optpage_title</b><br />\n".
                 html_tag( 'table', '', '', '', 'width="100%" cellpadding="5" cellspacing="0" border="0"' ) . "\n" .
                     html_tag( 'tr' ) . "\n" .
                         html_tag( 'td', '', 'center', $color[4] ) . "\n";
@@ -285,15 +292,26 @@ if ($optpage == SMOPT_PAGE_MAIN) {
         if (!isset($frame_top)) {
             $frame_top = '_top';
         }
-        /* Display a message indicating a successful save. */
-        echo '<b>' . _("Successfully Saved Options") . ": $optpage_name</b><br>\n";
+
+        if (isset($optpage_save_error) && $optpage_save_error!=array()) {
+            echo "<font color=\"$color[2]\"><b>" . _("Error(s) occurred while saving your options") . "</b></font><br />\n";
+            echo "<ul>\n";
+            foreach ($optpage_save_error as $error_message) {
+                echo '<li><small>' . $error_message . "</small></li>\n";
+            }
+            echo "</ul>\n";
+            echo '<b>' . _("Some of your preference changes were not applied.") . "</b><br />\n";
+        } else {
+            /* Display a message indicating a successful save. */
+            echo '<b>' . _("Successfully Saved Options") . ": $optpage_name</b><br />\n";
+        }
 
         /* If $max_refresh != SMOPT_REFRESH_NONE, provide a refresh link. */
         if ( !isset( $max_refresh ) ) {
         } else if ($max_refresh == SMOPT_REFRESH_FOLDERLIST) {
-            echo '<a href="../src/left_main.php" target="left">' . _("Refresh Folder List") . '</a><br>';
+            echo '<a href="../src/left_main.php" target="left">' . _("Refresh Folder List") . '</a><br />';
         } else if ($max_refresh) {
-            echo '<a href="../src/webmail.php?right_frame=options.php" target="' . $frame_top . '">' . _("Refresh Page") . '</a><br>';
+            echo '<a href="../src/webmail.php?right_frame=options.php" target="' . $frame_top . '">' . _("Refresh Page") . '</a><br />';
         }
     }
     /******************************************/
@@ -321,7 +339,7 @@ if ($optpage == SMOPT_PAGE_MAIN) {
     $optpage_blocks[] = array(
         'name' =>_("Message Highlighting"),
         'url'  => 'options_highlight.php',
-        'desc' =>_("Based upon given criteria, incoming messages can have different background colors in the message list.  This helps to easily distinguish who the messages are from, especially for mailing lists."),
+        'desc' =>_("Based upon given criteria, incoming messages can have different background colors in the message list. This helps to easily distinguish who the messages are from, especially for mailing lists."),
         'js'   => false
     );
 
@@ -447,11 +465,9 @@ if ($optpage == SMOPT_PAGE_MAIN) {
         do_hook($bottom_hook_name);    
     }
 }
-
-echo        '</td></tr>' .
-        '</table>'.
-        '</td></tr>'.
-     '</table>' .
-     '</body></html>';
-
 ?>
+</td></tr>
+</table>
+</td></tr>
+</table>
+</body></html>
\ No newline at end of file
